#  Coin Change Problem  
#  you are given a list of coin denominations, and you have an infinte supply of those denominations
#  you are also given a money amount to make change for
#  find out how many different combinations of coins can make change for a specific money amount
#
#  note, that different orderings of the same combinations of coins do not count multiple times
#  for instance, if you are making change for 3,  [1, 1, 1] is unique from [1,2]  however
#  [1,2] is not unique from [2,1]


memoization = {}     # this will be a dictionary to hold the solved sub-problems

# recursively call this subroutine in order to count the number of ways change can be made
def coin_change(amount,coin_list):

    if (amount <= 0):  # if the money to make change for is zero or negative
        return 0
        
    if (len(coin_list) == 0):  # if the coin list is empty
        return 0 
    
    if (coin_list[-1] <= 0):   # can't have negative coins, or zero value coins
        return 0
    
    memo = (amount,tuple(coin_list))  # make an unhashable value to see if this subproblem has been solved
    
    if (memo in memoization):
        return memoization[memo]
        
    if ( amount - coin_list[-1] == 0):  # if the largest coin makes exact change
        solution = 1 + coin_change(amount,coin_list[:-1])  # count it as 1, solve for the smaller coins in the set
    else:
        # otherwise subtract the largest coin as one subproblem, and remove the largest coin as the other subproblem
        solution =  coin_change(amount - coin_list[-1],coin_list) + coin_change(amount,coin_list[:-1])

    # save the solution in the dictionary        
    memoization[memo] = solution
    return solution
    
# Hardcoded input    
amount = 20
coin_list = [1,2,4,6,8]

# input format to get the data from the user interactively instead of hardcoded
#amount = int(raw_input().split()[0])
#coin_list = [int(x) for x in raw_input().split()]


coin_list.sort()
solution = coin_change(amount,coin_list)

print solution